@@ -89,16 +89,10 @@ class DocManager(DocManagerBase):
 
     def remove(self, document_id, namespace, timestamp):
         """Removes a document from Neo4j."""
-        doc_id = u(document_id)
-        tx = self.graph.begin()
-        statement = "MATCH (d:Document) WHERE d._id={} OPTIONAL MATCH (d)-[r]-() DELETE d, r".format(doc_id)
-        tx.run(statement)
-        tx.commit()
+        pass
 
     def search(self, start_ts, end_ts):
-        statement = "MATCH (d:Document) WHERE d._ts>={start_ts} AND d._ts<={end_ts} RETURN d".format(start_ts=start_ts, end_ts=end_ts)
-        results = self.graph.run(statement)
-        return results
+        pass
 
     def get_last_doc(self):
         """Get the most recently modified node from Neo4j.
